@echo off
SETLOCAL

set DATA_DIR=%1
set MODEL_NAME=%2
set SKYLINE_FILE=%3
set PROCESSES=6

set STARTTIME=%TIME%

set SKYD_FILE="%ROOT_ANALYSIS_DIR%\%SKYLINE_FILE%d"
set REPORT_NAME=PeakAreasScored.csv

echo [%STARTTIME%] Running trial %MODEL_NAME%...
echo [%STARTTIME%] Running trial %MODEL_NAME%... >> %LOG%

rem Get rid of the skyd file from previous analysis, so it doesn't get re-used in this analysis
if exist %SKYD_FILE% del /f /q %SKYD_FILE%

rem GOTO RSCRIPT
rem GOTO REPORT

rem Get rid of the skyd file from previous analysis, so it doesn't get re-used in this analysis
rem if exist %SKYD_FILE% del /f /q %SKYD_FILE%

rem Save to new location to allow parallel processing
echo %SKYLINE_RUNNER% --timestamp --dir="%ROOT_ANALYSIS_DIR%" --in="%SKYLINE_FILE%" --out="%DATA_DIR%\%MODEL_NAME%\%SKYLINE_FILE%" >> %LOG%
%SKYLINE_RUNNER% --timestamp --dir="%ROOT_ANALYSIS_DIR%" --in="%SKYLINE_FILE%" --out="%DATA_DIR%\%MODEL_NAME%\%SKYLINE_FILE%" >> %LOG%
if %ERRORLEVEL% NEQ 0 GOTO END

rem Do the analysis in the new location
:IMPORT
rem --import-naming-pattern="Site2_AQUA_HEK_(.*)_180714$"
echo %SKYLINE_RUNNER% --timestamp --import-process-count=%PROCESSES% --dir="%ROOT_ANALYSIS_DIR%" --in="%DATA_DIR%\%MODEL_NAME%\%SKYLINE_FILE%" --import-all="%DATA_DIR%" --import-naming-pattern="_([^_]*)$" --reintegrate-model-name="%MODEL_NAME%" --reintegrate-create-model --reintegrate-overwrite-peaks --out="%DATA_DIR%\%MODEL_NAME%\%SKYLINE_FILE%" --report-add="%ROOT_ANALYSIS_DIR%\scripts\PeakAreas.skyr" --report-conflict-resolution=overwrite --report-name="Precursor Peak Areas Scored" --report-file="%DATA_DIR%\%MODEL_NAME%\%REPORT_NAME%" --report-invariant >> %LOG%
%SKYLINE_RUNNER% --timestamp --import-process-count=%PROCESSES% --dir="%ROOT_ANALYSIS_DIR%" --in="%DATA_DIR%\%MODEL_NAME%\%SKYLINE_FILE%" --import-all="%DATA_DIR%" --import-naming-pattern="_([^_]*)$" --reintegrate-model-name="%MODEL_NAME%" --reintegrate-create-model --reintegrate-overwrite-peaks --out="%DATA_DIR%\%MODEL_NAME%\%SKYLINE_FILE%" --report-add="%ROOT_ANALYSIS_DIR%\scripts\PeakAreas.skyr" --report-conflict-resolution=overwrite --report-name="Precursor Peak Areas Scored" --report-file="%DATA_DIR%\%MODEL_NAME%\%REPORT_NAME%" --report-invariant >> %LOG%
rem echo %SKYLINE_RUNNER% --timestamp --dir="%ROOT_ANALYSIS_DIR%" --in="%DATA_DIR%\%MODEL_NAME%\%SKYLINE_FILE%" --reintegrate-model-name="%MODEL_NAME%" --reintegrate-create-model --reintegrate-overwrite-peaks >> %LOG%
rem %SKYLINE_RUNNER% --timestamp --dir="%ROOT_ANALYSIS_DIR%" --in="%DATA_DIR%\%MODEL_NAME%\%SKYLINE_FILE%" --reintegrate-model-name="%MODEL_NAME%" --reintegrate-create-model --reintegrate-overwrite-peaks >> %LOG%

if %ERRORLEVEL% NEQ 0 GOTO END

rem Skip extra report step, if it was generated by run above
GOTO RSCRIPT
rem Output report only for completed analysis
:REPORT
%SKYLINE_RUNNER% --timestamp --dir="%ROOT_ANALYSIS_DIR%" --in="%DATA_DIR%\%MODEL_NAME%\%SKYLINE_FILE%" --report-name="Precursor Peak Areas Scored" --report-file="%DATA_DIR%\%MODEL_NAME%\%REPORT_NAME%" --report-invariant >> %LOG%
if %ERRORLEVEL% NEQ 0 GOTO END

:RSCRIPT
rem Run analysis scripts in R
set Analysis_Script="%ROOT_ANALYSIS_DIR%\scripts\detection.R"

%R_Script% %Analysis_Script% "%ROOT_ANALYSIS_DIR%\%DATA_DIR%\%MODEL_NAME%\%REPORT_NAME%" >> %LOG% 2>&1

:END

set ENDTIME=%TIME%

rem Change formatting for the start and end times
for /F "tokens=1-4 delims=:.," %%a in ("%STARTTIME%") do (
   set /A "start=(((%%a*60)+1%%b %% 100)*60+1%%c %% 100)*100+1%%d %% 100"
)
for /F "tokens=1-4 delims=:.," %%a in ("%ENDTIME%") do (
   set /A "end=(((%%a*60)+1%%b %% 100)*60+1%%c %% 100)*100+1%%d %% 100"
)

rem Calculate the elapsed time by subtracting values
set /A elapsed=end-start
rem we might have measured the time inbetween days
if %end% LSS %start% set /A elapsed=(24*60*60*100 - start) + end

    rem Format the results for output
set /A hh=elapsed/(60*60*100), rest=elapsed%%(60*60*100), mm=rest/(60*100), rest%%=60*100, ss=rest/100, cc=rest%%100
if %hh% lss 10 set hh=0%hh%
if %mm% lss 10 set mm=0%mm%
if %ss% lss 10 set ss=0%ss%
if %cc% lss 10 set cc=0%cc%

set DURATION=%hh%:%mm%:%ss%.%cc%

echo. >> %LOG%
echo [%ENDTIME%] Completed trial %MODEL_NAME%... >> %LOG%
echo [%ENDTIME%] =^> Elapsed time: %DURATION%
echo [%ENDTIME%] =^> Elapsed time: %DURATION% >> %LOG%
echo. >> %LOG%
echo. >> %LOG%

ENDLOCAL